#include "tex_matrix.fx"

float2 gUVPrePosition = float2( 0, 0 );
float2 gUVScale = float( 1 );                     // UV scale
float2 gUVScaleCenter = float2( 0.5, 0.5 );
float gUVRotAngle = float( 0 );                   // UV Rotation
float2 gUVRotCenter = float2( 0.5, 0.5 );
float2 gUVPosition = float2( 0, 0 );              // UV position

//-------------------------------------------
// Returns UV transform using external settings
//-------------------------------------------
float3x3 getTextureTransform()
{
    return makeTextureTransform( gUVPrePosition, gUVScale, gUVScaleCenter, gUVRotAngle, gUVRotCenter, gUVPosition );
}

texture gTexture;
sampler gTextureSampler = sampler_state 
{ 
    Texture = <gTexture>; 
}; 
  
texture gMaskTexture; 
sampler gMaskTextureSampler = sampler_state 
{ 
    Texture = <gMaskTexture>; 
};

texture gRectangles; 
sampler gRectanglesSampler = sampler_state 
{ 
    Texture = <gRectangles>; 
}; 

texture sMaskTexture;

float4 PixelShaderFunction(float2 TexCoord : TEXCOORD0) : COLOR0
{
    float4 color = tex2D(gTextureSampler, TexCoord); 
    float4 mask = tex2D(gMaskTextureSampler, TexCoord); 
    color.a = mask.a;
	float4 rectangle = tex2D(gRectanglesSampler, TexCoord);
	// Next going fix for out border Bugs
	if (TexCoord.y < 0.999 && TexCoord.y > 0.001 && TexCoord.x < 0.999 && TexCoord.x > 0.001) {
		color *= rectangle;
	}
	else
	{
		TexCoord.x = 1;
		TexCoord.y = 1;
		color = tex2D(gTextureSampler, TexCoord);
	}
	// to here
	// here fix Alpha of GangZones
	color.a = 0.96;
    return color; 
} 
  
technique 
{ 
    pass P0 
    { 
        // Enable Alpha Blend
        AlphaBlendEnable = true; 
        SrcBlend = SrcAlpha; 
        DestBlend = InvSrcAlpha;
    
        // Set up texture stage 0
        //PixelShader = compile ps_2_0 PixelShaderFunction();
        
        Texture[0] = gTexture;
        TextureTransform[0] = getTextureTransform();
        TextureTransformFlags[0] = Count2;
        AddressU[0] = Clamp;
        AddressV[0] = Clamp;
        ColorOp[0] = Modulate;
        ColorArg1[0] = Texture;
        ColorArg2[0] = Diffuse;
        // Alpha mix texture and diffuse
        AlphaOp[0] = Modulate;
        AlphaArg1[0] = Texture;
        AlphaArg2[0] = Diffuse;

        Texture[1] = sMaskTexture;
        TexCoordIndex[1] = 0;
        AddressU[1] = Clamp;
        AddressV[1] = Clamp;
        // Color pass through from stage 0
        ColorOp[1] = SelectArg1;
        ColorArg1[1] = Current;
        // Alpha modulate mask texture with stage 0
        AlphaOp[1] = Modulate;
        AlphaArg1[1] = Current;
        AlphaArg2[1] = Texture;

        ColorOp[2] = Disable;
        AlphaOp[2] = Disable;

    } 
} 